@@ -1,6 +1,8 @@
 package Alt::CWB::CL::ambs;
 
-our $VERSION = '2.2.102.0';
+use warnings;
+use strict;
+our $VERSION = '2.2.102.1';
 
 1;
 
