@@ -1,5 +1,7 @@
 package CWB::CL::Strict;
 
+use warnings;
+use strict;
 # this is just a convenient wrapper to load CWB::CL with "strict" mode enabled
 use CWB::CL;
 CWB::CL::strict(1);
